from os.path import abspath, dirname

from setuptools import setup


LONG_DESCRIPTION = open(dirname(abspath(__file__)) + "/README.md", "r").read()


setup(
    name="boto3-stubs",
    version="1.10.36.1",
    packages=["boto3-stubs"],
    url="https://github.com/vemel/mypy_boto3",
    license="MIT License",
    author="Vlad Emelianov",
    author_email="vlad.emelianov.nz@gmail.com",
    description="Boto3 1.10.37 stubs powered by `mypy-boto3`.",
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "Environment :: Console",
        "License :: OSI Approved :: MIT License",
        "Natural Language :: English",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: Implementation :: CPython",
        "Typing :: Typed",
    ],
    long_description=LONG_DESCRIPTION,
    long_description_content_type="text/markdown",
    package_data={"boto3-stubs": ["py.typed", "*.pyi", "*/*.pyi"]},
    install_requires=["typing_extensions; python_version < '3.8'",],
    extras_require={
        "master": ["mypy-boto3==1.10.36.1"],
        "essential": [
            "mypy-boto3-cloudformation[master]==1.10.36.1",
            "mypy-boto3-dynamodb[master]==1.10.36.1",
            "mypy-boto3-ec2[master]==1.10.36.1",
            "mypy-boto3-lambda[master]==1.10.36.1",
            "mypy-boto3-rds[master]==1.10.36.1",
            "mypy-boto3-s3[master]==1.10.36.1",
            "mypy-boto3-sqs[master]==1.10.36.1",
        ],
        "accessanalyzer": ["mypy-boto3-accessanalyzer[master]==1.10.36.1"],
        "acm": ["mypy-boto3-acm[master]==1.10.36.1"],
        "acm-pca": ["mypy-boto3-acm-pca[master]==1.10.36.1"],
        "alexaforbusiness": ["mypy-boto3-alexaforbusiness[master]==1.10.36.1"],
        "amplify": ["mypy-boto3-amplify[master]==1.10.36.1"],
        "apigateway": ["mypy-boto3-apigateway[master]==1.10.36.1"],
        "apigatewaymanagementapi": ["mypy-boto3-apigatewaymanagementapi[master]==1.10.36.1"],
        "apigatewayv2": ["mypy-boto3-apigatewayv2[master]==1.10.36.1"],
        "appconfig": ["mypy-boto3-appconfig[master]==1.10.36.1"],
        "application-autoscaling": ["mypy-boto3-application-autoscaling[master]==1.10.36.1"],
        "application-insights": ["mypy-boto3-application-insights[master]==1.10.36.1"],
        "appmesh": ["mypy-boto3-appmesh[master]==1.10.36.1"],
        "appstream": ["mypy-boto3-appstream[master]==1.10.36.1"],
        "appsync": ["mypy-boto3-appsync[master]==1.10.36.1"],
        "athena": ["mypy-boto3-athena[master]==1.10.36.1"],
        "autoscaling": ["mypy-boto3-autoscaling[master]==1.10.36.1"],
        "autoscaling-plans": ["mypy-boto3-autoscaling-plans[master]==1.10.36.1"],
        "backup": ["mypy-boto3-backup[master]==1.10.36.1"],
        "batch": ["mypy-boto3-batch[master]==1.10.36.1"],
        "budgets": ["mypy-boto3-budgets[master]==1.10.36.1"],
        "ce": ["mypy-boto3-ce[master]==1.10.36.1"],
        "chime": ["mypy-boto3-chime[master]==1.10.36.1"],
        "cloud9": ["mypy-boto3-cloud9[master]==1.10.36.1"],
        "clouddirectory": ["mypy-boto3-clouddirectory[master]==1.10.36.1"],
        "cloudformation": ["mypy-boto3-cloudformation[master]==1.10.36.1"],
        "cloudfront": ["mypy-boto3-cloudfront[master]==1.10.36.1"],
        "cloudhsm": ["mypy-boto3-cloudhsm[master]==1.10.36.1"],
        "cloudhsmv2": ["mypy-boto3-cloudhsmv2[master]==1.10.36.1"],
        "cloudsearch": ["mypy-boto3-cloudsearch[master]==1.10.36.1"],
        "cloudsearchdomain": ["mypy-boto3-cloudsearchdomain[master]==1.10.36.1"],
        "cloudtrail": ["mypy-boto3-cloudtrail[master]==1.10.36.1"],
        "cloudwatch": ["mypy-boto3-cloudwatch[master]==1.10.36.1"],
        "codebuild": ["mypy-boto3-codebuild[master]==1.10.36.1"],
        "codecommit": ["mypy-boto3-codecommit[master]==1.10.36.1"],
        "codedeploy": ["mypy-boto3-codedeploy[master]==1.10.36.1"],
        "codeguru-reviewer": ["mypy-boto3-codeguru-reviewer[master]==1.10.36.1"],
        "codeguruprofiler": ["mypy-boto3-codeguruprofiler[master]==1.10.36.1"],
        "codepipeline": ["mypy-boto3-codepipeline[master]==1.10.36.1"],
        "codestar": ["mypy-boto3-codestar[master]==1.10.36.1"],
        "codestar-notifications": ["mypy-boto3-codestar-notifications[master]==1.10.36.1"],
        "cognito-identity": ["mypy-boto3-cognito-identity[master]==1.10.36.1"],
        "cognito-idp": ["mypy-boto3-cognito-idp[master]==1.10.36.1"],
        "cognito-sync": ["mypy-boto3-cognito-sync[master]==1.10.36.1"],
        "comprehend": ["mypy-boto3-comprehend[master]==1.10.36.1"],
        "comprehendmedical": ["mypy-boto3-comprehendmedical[master]==1.10.36.1"],
        "compute-optimizer": ["mypy-boto3-compute-optimizer[master]==1.10.36.1"],
        "config": ["mypy-boto3-config[master]==1.10.36.1"],
        "connect": ["mypy-boto3-connect[master]==1.10.36.1"],
        "connectparticipant": ["mypy-boto3-connectparticipant[master]==1.10.36.1"],
        "cur": ["mypy-boto3-cur[master]==1.10.36.1"],
        "dataexchange": ["mypy-boto3-dataexchange[master]==1.10.36.1"],
        "datapipeline": ["mypy-boto3-datapipeline[master]==1.10.36.1"],
        "datasync": ["mypy-boto3-datasync[master]==1.10.36.1"],
        "dax": ["mypy-boto3-dax[master]==1.10.36.1"],
        "devicefarm": ["mypy-boto3-devicefarm[master]==1.10.36.1"],
        "directconnect": ["mypy-boto3-directconnect[master]==1.10.36.1"],
        "discovery": ["mypy-boto3-discovery[master]==1.10.36.1"],
        "dlm": ["mypy-boto3-dlm[master]==1.10.36.1"],
        "dms": ["mypy-boto3-dms[master]==1.10.36.1"],
        "docdb": ["mypy-boto3-docdb[master]==1.10.36.1"],
        "ds": ["mypy-boto3-ds[master]==1.10.36.1"],
        "dynamodb": ["mypy-boto3-dynamodb[master]==1.10.36.1"],
        "dynamodbstreams": ["mypy-boto3-dynamodbstreams[master]==1.10.36.1"],
        "ebs": ["mypy-boto3-ebs[master]==1.10.36.1"],
        "ec2": ["mypy-boto3-ec2[master]==1.10.36.1"],
        "ec2-instance-connect": ["mypy-boto3-ec2-instance-connect[master]==1.10.36.1"],
        "ecr": ["mypy-boto3-ecr[master]==1.10.36.1"],
        "ecs": ["mypy-boto3-ecs[master]==1.10.36.1"],
        "efs": ["mypy-boto3-efs[master]==1.10.36.1"],
        "eks": ["mypy-boto3-eks[master]==1.10.36.1"],
        "elastic-inference": ["mypy-boto3-elastic-inference[master]==1.10.36.1"],
        "elasticache": ["mypy-boto3-elasticache[master]==1.10.36.1"],
        "elasticbeanstalk": ["mypy-boto3-elasticbeanstalk[master]==1.10.36.1"],
        "elastictranscoder": ["mypy-boto3-elastictranscoder[master]==1.10.36.1"],
        "elb": ["mypy-boto3-elb[master]==1.10.36.1"],
        "elbv2": ["mypy-boto3-elbv2[master]==1.10.36.1"],
        "emr": ["mypy-boto3-emr[master]==1.10.36.1"],
        "es": ["mypy-boto3-es[master]==1.10.36.1"],
        "events": ["mypy-boto3-events[master]==1.10.36.1"],
        "firehose": ["mypy-boto3-firehose[master]==1.10.36.1"],
        "fms": ["mypy-boto3-fms[master]==1.10.36.1"],
        "forecast": ["mypy-boto3-forecast[master]==1.10.36.1"],
        "forecastquery": ["mypy-boto3-forecastquery[master]==1.10.36.1"],
        "frauddetector": ["mypy-boto3-frauddetector[master]==1.10.36.1"],
        "fsx": ["mypy-boto3-fsx[master]==1.10.36.1"],
        "gamelift": ["mypy-boto3-gamelift[master]==1.10.36.1"],
        "glacier": ["mypy-boto3-glacier[master]==1.10.36.1"],
        "globalaccelerator": ["mypy-boto3-globalaccelerator[master]==1.10.36.1"],
        "glue": ["mypy-boto3-glue[master]==1.10.36.1"],
        "greengrass": ["mypy-boto3-greengrass[master]==1.10.36.1"],
        "groundstation": ["mypy-boto3-groundstation[master]==1.10.36.1"],
        "guardduty": ["mypy-boto3-guardduty[master]==1.10.36.1"],
        "health": ["mypy-boto3-health[master]==1.10.36.1"],
        "iam": ["mypy-boto3-iam[master]==1.10.36.1"],
        "imagebuilder": ["mypy-boto3-imagebuilder[master]==1.10.36.1"],
        "importexport": ["mypy-boto3-importexport[master]==1.10.36.1"],
        "inspector": ["mypy-boto3-inspector[master]==1.10.36.1"],
        "iot": ["mypy-boto3-iot[master]==1.10.36.1"],
        "iot-data": ["mypy-boto3-iot-data[master]==1.10.36.1"],
        "iot-jobs-data": ["mypy-boto3-iot-jobs-data[master]==1.10.36.1"],
        "iot1click-devices": ["mypy-boto3-iot1click-devices[master]==1.10.36.1"],
        "iot1click-projects": ["mypy-boto3-iot1click-projects[master]==1.10.36.1"],
        "iotanalytics": ["mypy-boto3-iotanalytics[master]==1.10.36.1"],
        "iotevents": ["mypy-boto3-iotevents[master]==1.10.36.1"],
        "iotevents-data": ["mypy-boto3-iotevents-data[master]==1.10.36.1"],
        "iotsecuretunneling": ["mypy-boto3-iotsecuretunneling[master]==1.10.36.1"],
        "iotthingsgraph": ["mypy-boto3-iotthingsgraph[master]==1.10.36.1"],
        "kafka": ["mypy-boto3-kafka[master]==1.10.36.1"],
        "kendra": ["mypy-boto3-kendra[master]==1.10.36.1"],
        "kinesis": ["mypy-boto3-kinesis[master]==1.10.36.1"],
        "kinesis-video-archived-media": [
            "mypy-boto3-kinesis-video-archived-media[master]==1.10.36.1"
        ],
        "kinesis-video-media": ["mypy-boto3-kinesis-video-media[master]==1.10.36.1"],
        "kinesis-video-signaling": ["mypy-boto3-kinesis-video-signaling[master]==1.10.36.1"],
        "kinesisanalytics": ["mypy-boto3-kinesisanalytics[master]==1.10.36.1"],
        "kinesisanalyticsv2": ["mypy-boto3-kinesisanalyticsv2[master]==1.10.36.1"],
        "kinesisvideo": ["mypy-boto3-kinesisvideo[master]==1.10.36.1"],
        "kms": ["mypy-boto3-kms[master]==1.10.36.1"],
        "lakeformation": ["mypy-boto3-lakeformation[master]==1.10.36.1"],
        "lambda": ["mypy-boto3-lambda[master]==1.10.36.1"],
        "lex-models": ["mypy-boto3-lex-models[master]==1.10.36.1"],
        "lex-runtime": ["mypy-boto3-lex-runtime[master]==1.10.36.1"],
        "license-manager": ["mypy-boto3-license-manager[master]==1.10.36.1"],
        "lightsail": ["mypy-boto3-lightsail[master]==1.10.36.1"],
        "logs": ["mypy-boto3-logs[master]==1.10.36.1"],
        "machinelearning": ["mypy-boto3-machinelearning[master]==1.10.36.1"],
        "macie": ["mypy-boto3-macie[master]==1.10.36.1"],
        "managedblockchain": ["mypy-boto3-managedblockchain[master]==1.10.36.1"],
        "marketplace-catalog": ["mypy-boto3-marketplace-catalog[master]==1.10.36.1"],
        "marketplace-entitlement": ["mypy-boto3-marketplace-entitlement[master]==1.10.36.1"],
        "marketplacecommerceanalytics": [
            "mypy-boto3-marketplacecommerceanalytics[master]==1.10.36.1"
        ],
        "mediaconnect": ["mypy-boto3-mediaconnect[master]==1.10.36.1"],
        "mediaconvert": ["mypy-boto3-mediaconvert[master]==1.10.36.1"],
        "medialive": ["mypy-boto3-medialive[master]==1.10.36.1"],
        "mediapackage": ["mypy-boto3-mediapackage[master]==1.10.36.1"],
        "mediapackage-vod": ["mypy-boto3-mediapackage-vod[master]==1.10.36.1"],
        "mediastore": ["mypy-boto3-mediastore[master]==1.10.36.1"],
        "mediastore-data": ["mypy-boto3-mediastore-data[master]==1.10.36.1"],
        "mediatailor": ["mypy-boto3-mediatailor[master]==1.10.36.1"],
        "meteringmarketplace": ["mypy-boto3-meteringmarketplace[master]==1.10.36.1"],
        "mgh": ["mypy-boto3-mgh[master]==1.10.36.1"],
        "migrationhub-config": ["mypy-boto3-migrationhub-config[master]==1.10.36.1"],
        "mobile": ["mypy-boto3-mobile[master]==1.10.36.1"],
        "mq": ["mypy-boto3-mq[master]==1.10.36.1"],
        "mturk": ["mypy-boto3-mturk[master]==1.10.36.1"],
        "neptune": ["mypy-boto3-neptune[master]==1.10.36.1"],
        "networkmanager": ["mypy-boto3-networkmanager[master]==1.10.36.1"],
        "opsworks": ["mypy-boto3-opsworks[master]==1.10.36.1"],
        "opsworkscm": ["mypy-boto3-opsworkscm[master]==1.10.36.1"],
        "organizations": ["mypy-boto3-organizations[master]==1.10.36.1"],
        "outposts": ["mypy-boto3-outposts[master]==1.10.36.1"],
        "personalize": ["mypy-boto3-personalize[master]==1.10.36.1"],
        "personalize-events": ["mypy-boto3-personalize-events[master]==1.10.36.1"],
        "personalize-runtime": ["mypy-boto3-personalize-runtime[master]==1.10.36.1"],
        "pi": ["mypy-boto3-pi[master]==1.10.36.1"],
        "pinpoint": ["mypy-boto3-pinpoint[master]==1.10.36.1"],
        "pinpoint-email": ["mypy-boto3-pinpoint-email[master]==1.10.36.1"],
        "pinpoint-sms-voice": ["mypy-boto3-pinpoint-sms-voice[master]==1.10.36.1"],
        "polly": ["mypy-boto3-polly[master]==1.10.36.1"],
        "pricing": ["mypy-boto3-pricing[master]==1.10.36.1"],
        "qldb": ["mypy-boto3-qldb[master]==1.10.36.1"],
        "qldb-session": ["mypy-boto3-qldb-session[master]==1.10.36.1"],
        "quicksight": ["mypy-boto3-quicksight[master]==1.10.36.1"],
        "ram": ["mypy-boto3-ram[master]==1.10.36.1"],
        "rds": ["mypy-boto3-rds[master]==1.10.36.1"],
        "rds-data": ["mypy-boto3-rds-data[master]==1.10.36.1"],
        "redshift": ["mypy-boto3-redshift[master]==1.10.36.1"],
        "rekognition": ["mypy-boto3-rekognition[master]==1.10.36.1"],
        "resource-groups": ["mypy-boto3-resource-groups[master]==1.10.36.1"],
        "resourcegroupstaggingapi": ["mypy-boto3-resourcegroupstaggingapi[master]==1.10.36.1"],
        "robomaker": ["mypy-boto3-robomaker[master]==1.10.36.1"],
        "route53": ["mypy-boto3-route53[master]==1.10.36.1"],
        "route53domains": ["mypy-boto3-route53domains[master]==1.10.36.1"],
        "route53resolver": ["mypy-boto3-route53resolver[master]==1.10.36.1"],
        "s3": ["mypy-boto3-s3[master]==1.10.36.1"],
        "s3control": ["mypy-boto3-s3control[master]==1.10.36.1"],
        "sagemaker": ["mypy-boto3-sagemaker[master]==1.10.36.1"],
        "sagemaker-a2i-runtime": ["mypy-boto3-sagemaker-a2i-runtime[master]==1.10.36.1"],
        "sagemaker-runtime": ["mypy-boto3-sagemaker-runtime[master]==1.10.36.1"],
        "savingsplans": ["mypy-boto3-savingsplans[master]==1.10.36.1"],
        "schemas": ["mypy-boto3-schemas[master]==1.10.36.1"],
        "sdb": ["mypy-boto3-sdb[master]==1.10.36.1"],
        "secretsmanager": ["mypy-boto3-secretsmanager[master]==1.10.36.1"],
        "securityhub": ["mypy-boto3-securityhub[master]==1.10.36.1"],
        "serverlessrepo": ["mypy-boto3-serverlessrepo[master]==1.10.36.1"],
        "service-quotas": ["mypy-boto3-service-quotas[master]==1.10.36.1"],
        "servicecatalog": ["mypy-boto3-servicecatalog[master]==1.10.36.1"],
        "servicediscovery": ["mypy-boto3-servicediscovery[master]==1.10.36.1"],
        "ses": ["mypy-boto3-ses[master]==1.10.36.1"],
        "sesv2": ["mypy-boto3-sesv2[master]==1.10.36.1"],
        "shield": ["mypy-boto3-shield[master]==1.10.36.1"],
        "signer": ["mypy-boto3-signer[master]==1.10.36.1"],
        "sms": ["mypy-boto3-sms[master]==1.10.36.1"],
        "sms-voice": ["mypy-boto3-sms-voice[master]==1.10.36.1"],
        "snowball": ["mypy-boto3-snowball[master]==1.10.36.1"],
        "sns": ["mypy-boto3-sns[master]==1.10.36.1"],
        "sqs": ["mypy-boto3-sqs[master]==1.10.36.1"],
        "ssm": ["mypy-boto3-ssm[master]==1.10.36.1"],
        "sso": ["mypy-boto3-sso[master]==1.10.36.1"],
        "sso-oidc": ["mypy-boto3-sso-oidc[master]==1.10.36.1"],
        "stepfunctions": ["mypy-boto3-stepfunctions[master]==1.10.36.1"],
        "storagegateway": ["mypy-boto3-storagegateway[master]==1.10.36.1"],
        "sts": ["mypy-boto3-sts[master]==1.10.36.1"],
        "support": ["mypy-boto3-support[master]==1.10.36.1"],
        "swf": ["mypy-boto3-swf[master]==1.10.36.1"],
        "textract": ["mypy-boto3-textract[master]==1.10.36.1"],
        "transcribe": ["mypy-boto3-transcribe[master]==1.10.36.1"],
        "transfer": ["mypy-boto3-transfer[master]==1.10.36.1"],
        "translate": ["mypy-boto3-translate[master]==1.10.36.1"],
        "waf": ["mypy-boto3-waf[master]==1.10.36.1"],
        "waf-regional": ["mypy-boto3-waf-regional[master]==1.10.36.1"],
        "wafv2": ["mypy-boto3-wafv2[master]==1.10.36.1"],
        "workdocs": ["mypy-boto3-workdocs[master]==1.10.36.1"],
        "worklink": ["mypy-boto3-worklink[master]==1.10.36.1"],
        "workmail": ["mypy-boto3-workmail[master]==1.10.36.1"],
        "workmailmessageflow": ["mypy-boto3-workmailmessageflow[master]==1.10.36.1"],
        "workspaces": ["mypy-boto3-workspaces[master]==1.10.36.1"],
        "xray": ["mypy-boto3-xray[master]==1.10.36.1"],
    },
    zip_safe=False,
)
